#!/usr/bin/env python
import json
import pandas as pd
from tooldistillator.interfaces import (
    ToolDistillatorResultIterator,
)

required_metadata = {
    "hid": "Historic ID to refseq result from Galaxy",
    "reference_database_version": "DB version",
    "analysis_software_version": "refseqmasher version number",
}


class RefseqmasherIterator(ToolDistillatorResultIterator):
    """Refseqmasher tool parser
    Filter results from refseq tabular file

    Args:
        ToolDistillatorResultIterator: abstract class to the parser
    """

    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "refseqmasher"
        self.metadata = metadata
        super().__init__(source, metadata)
        self.tooldistillator_results["tool_has_database"] = False
        self.parse()

    def parse(self):
        """Refseqmasher matches parser"""
        refseq_df = pd.read_table(self.source)
        refseq_json = refseq_df.to_json(
            orient="records",
        )
        self.tooldistillator_results["results"][0][
            "content"
            ] = json.loads(refseq_json)
